You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by pi...@apache.org on 2007/03/30 20:28:34 UTC

svn commit: r524225 [20/22] - in /webservices/axis2/trunk/c: axiom/include/ axiom/src/attachments/ axiom/src/om/ axiom/src/parser/libxml2/ axiom/src/soap/ axiom/src/util/ include/ modules/core/addr/ modules/core/clientapi/ modules/core/context/ modules...

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema.h Fri Mar 30 11:28:18 2007
@@ -30,7 +30,7 @@
 #include <xml_schema_annotated.h>
 #include <axiom_element.h>
 #include <axiom_node.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 
 /** @defgroup xml_schema Xml Schema
   * @ingroup xml_schema
@@ -67,7 +67,7 @@
             void *schema,
             const axutil_env_t *env);
 
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs)(
             void *schema,
             const axutil_env_t *env);
@@ -219,7 +219,7 @@
             void *schema,
             void *writer); 
 
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     get_prefix_to_namespace_map)(
             void *schema,
             const axutil_env_t *env);
@@ -228,7 +228,7 @@
     set_prefix_to_namespace_map)(
             void *schema,
             const axutil_env_t *env,
-            axis2_hash_t *map);
+            axutil_hash_t *map);
 
     axis2_status_t (AXIS2_CALL *
     add_type)(

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_annotated.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_annotated.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_annotated.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_annotated.h Fri Mar 30 11:28:18 2007
@@ -68,7 +68,7 @@
      * @param env environment
      * @returns pointer to hashtable
      */
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs)(
             void *annotated,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_annotation.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_annotation.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_annotation.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_annotation.h Fri Mar 30 11:28:18 2007
@@ -31,7 +31,7 @@
 #include <xml_schema_defines.h>
 #include <xml_schema_obj.h>
 #include <xml_schema_obj_collection.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 
 #ifdef __cplusplus
 extern "C"
@@ -63,7 +63,7 @@
          * @returns pointer to hashtable if available ,NULL otherwise
          */
 
-        axis2_hash_t *(AXIS2_CALL *
+        axutil_hash_t *(AXIS2_CALL *
                 super_objs) (
                     void *annotation,
                     const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_any.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_any.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_any.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_any.h Fri Mar 30 11:28:18 2007
@@ -58,7 +58,7 @@
             void *any,
             const axutil_env_t *env);
 
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs) (
             void *any,
             const axutil_env_t *env);
@@ -109,7 +109,7 @@
            xml_schema_any_t *any,
            const axutil_env_t *env,
            xml_schema_any_t *any_impl,
-           axis2_hash_t *methods);
+           axutil_hash_t *methods);
  */
  /************************ Macros *******************************************/
  

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_any_attribute.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_any_attribute.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_any_attribute.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_any_attribute.h Fri Mar 30 11:28:18 2007
@@ -61,7 +61,7 @@
     get_type)(void *any_attr,
           const axutil_env_t *env);
           
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(void *any_attr,
                 const axutil_env_t *env);
                                       
@@ -106,7 +106,7 @@
                                 xml_schema_any_attribute_t *any_attr,
                                 const axutil_env_t *env,
                                 xml_schema_any_attribute_t *any_impl,
-                                axis2_hash_t *methods);
+                                axutil_hash_t *methods);
  */
 /******************************* Macros *************************************************/ 
  

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_app_info.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_app_info.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_app_info.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_app_info.h Fri Mar 30 11:28:18 2007
@@ -28,7 +28,7 @@
 
 #include <xml_schema_defines.h>
 #include <xml_schema_obj.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 
 /** @defgroup xml_schema_app_info Xml Schema App Info
   * @ingroup xml_schema
@@ -56,7 +56,7 @@
             void *app_info,
             const axutil_env_t *env);
 
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs) (
             void *app_info,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute.h Fri Mar 30 11:28:18 2007
@@ -63,7 +63,7 @@
             void *attr,
             const axutil_env_t *env);
           
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(
             void *attr,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group.h Fri Mar 30 11:28:18 2007
@@ -64,7 +64,7 @@
             void *attr_grp,
             const axutil_env_t *env);
           
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(
             void *attr_grp,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group_ref.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group_ref.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group_ref.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group_ref.h Fri Mar 30 11:28:18 2007
@@ -63,7 +63,7 @@
             void *grp_ref,
             const axutil_env_t *env);
           
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(
             void *grp_ref,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_builder.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_builder.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_builder.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_builder.h Fri Mar 30 11:28:18 2007
@@ -30,7 +30,7 @@
 #include <xml_schema_annotated.h>
 #include <xml_schema.h>
 #include <axiom.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <xml_schema_collection.h>
 #include <axiom_util.h>
 /** @defgroup xml_schema_builder Xml Schema

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_collection.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_collection.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_collection.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_collection.h Fri Mar 30 11:28:18 2007
@@ -31,7 +31,7 @@
 #include <axis2_utils.h>
 
 #include <axutil_array_list.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <axis2_qname.h>
 #include <xml_schema_obj.h>
 #include <axiom_xml_reader.h>
@@ -162,7 +162,7 @@
             axis2_char_t *prefix, 
             axis2_char_t *namespc_uri);
             
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     get_systemid2_schemas)(
             xml_schema_collection_t* collection,
             const axutil_env_t *env);
@@ -178,7 +178,7 @@
             const axutil_env_t *env,
             axutil_array_list_t *schemas);            
                       
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     get_namespaces)(
             xml_schema_collection_t *collection,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content.h Fri Mar 30 11:28:18 2007
@@ -28,7 +28,7 @@
  */
 
 #include <xml_schema_annotated.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 
 /** @defgroup xml_schema_complex_content Xml Schema Group
   * @ingroup xml_schema
@@ -59,7 +59,7 @@
     get_type) (void *complex_content,
             const axutil_env_t *env);
                     
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs) (void *complex_content,
                     const axutil_env_t *env);                                        
 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_extension.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_extension.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_extension.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_extension.h Fri Mar 30 11:28:18 2007
@@ -26,7 +26,7 @@
 #include <xml_schema_obj_collection.h>
 #include <xml_schema_any_attribute.h>
 #include <xml_schema_particle.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <axis2_qname.h>
 /** @defgroup xml_schema_complex_content_extension 
   * @ingroup xml_schema
@@ -59,7 +59,7 @@
             void *cmp_content_ext,
             const axutil_env_t *env);  
             
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(
             void *cmp_content_ext,
             const axutil_env_t *env);                      

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_restriction.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_restriction.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_restriction.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_restriction.h Fri Mar 30 11:28:18 2007
@@ -26,7 +26,7 @@
 #include <xml_schema_obj_collection.h>
 #include <xml_schema_any_attribute.h>
 #include <xml_schema_simple_type.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <axis2_qname.h>
 
 /** @defgroup xml_schema_complex_content_restriction Xml Schema Group
@@ -56,7 +56,7 @@
             void *cmp_content_res,
             const axutil_env_t *env);
             
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(
             void *cmp_content_res,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_type.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_type.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_type.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_type.h Fri Mar 30 11:28:18 2007
@@ -26,7 +26,7 @@
 
 #include <xml_schema_annotated.h>
 #include <xml_schema_type.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <axis2_qname.h>
 #include <xml_schema_complex_type.h>
 #include <xml_schema_any_attribute.h>
@@ -65,7 +65,7 @@
             void *cmp_type,
             const axutil_env_t *env);
             
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs)(
             void *cmp_type,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_constants.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_constants.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_constants.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_constants.h Fri Mar 30 11:28:18 2007
@@ -24,7 +24,7 @@
  */
  
 #include <axis2_utils.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <xml_schema_defines.h>
 
 #ifdef __cplusplus
@@ -102,7 +102,7 @@
 #define XML_SCHEMA_XSD_SCHEMA             "schema"
 
 
-typedef axis2_hash_t* (AXIS2_CALL *XML_SCHEMA_SUPER_OBJS_FN)(void *obj,
+typedef axutil_hash_t* (AXIS2_CALL *XML_SCHEMA_SUPER_OBJS_FN)(void *obj,
                                     const axutil_env_t *env);
                                     
 typedef xml_schema_types_t (AXIS2_CALL *XML_SCHEMA_GET_TYPE_FN)(void *obj, const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_content_processing.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_content_processing.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_content_processing.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_content_processing.h Fri Mar 30 11:28:18 2007
@@ -56,7 +56,7 @@
     free) (void *content_processing,
             const axutil_env_t *env);
 
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs) (void *content_processing,
             const axutil_env_t *env);
 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_content_type.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_content_type.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_content_type.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_content_type.h Fri Mar 30 11:28:18 2007
@@ -55,7 +55,7 @@
     free) (void *content_type,
             const axutil_env_t *env);
             
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs) (void *content_type,
             const axutil_env_t *env);
 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_data_type.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_data_type.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_data_type.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_data_type.h Fri Mar 30 11:28:18 2007
@@ -28,7 +28,7 @@
 #include <axutil_error.h>
 #include <axis2_string.h>
 #include <axutil_array_list.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 
 #ifdef __cplusplus
 extern "C"

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_derivation_method.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_derivation_method.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_derivation_method.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_derivation_method.h Fri Mar 30 11:28:18 2007
@@ -62,7 +62,7 @@
     get_values)(void *derivation_method,
                 const axutil_env_t *env);
                 
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(void *derivation_method,
                 const axutil_env_t *env);
     

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_documentation.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_documentation.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_documentation.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_documentation.h Fri Mar 30 11:28:18 2007
@@ -28,7 +28,7 @@
 
 #include <xml_schema_defines.h>
 #include <xml_schema_obj.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <axiom.h>
 
 /** @defgroup xml_schema_documentation Xml Schema App Info
@@ -57,7 +57,7 @@
             void *documentation,
             const axutil_env_t *env);
 
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs) (
             void *documentation,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_element.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_element.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_element.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_element.h Fri Mar 30 11:28:18 2007
@@ -62,7 +62,7 @@
     get_type)(void *element,
           const axutil_env_t *env);
           
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(void *element,
                 const axutil_env_t *env);          
 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_enum.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_enum.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_enum.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_enum.h Fri Mar 30 11:28:18 2007
@@ -29,7 +29,7 @@
 #include <axis2_string.h>
 #include <axis2_utils_defines.h>
 #include <axutil_array_list.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <xml_schema_defines.h>
 #include <xml_schema_constants.h>
 
@@ -53,7 +53,7 @@
             void *schema_enum,
             const axutil_env_t *env);
 
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs)(
             void *schema_enum,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_external.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_external.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_external.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_external.h Fri Mar 30 11:28:18 2007
@@ -25,7 +25,7 @@
  */
 
 #include <xml_schema_annotated.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 
 /** @defgroup xml_schema_external Xml Schema Particle
   * @ingroup xml_schema
@@ -65,7 +65,7 @@
             const axutil_env_t *env);            
 
 
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(
             void *external,
             const axutil_env_t *env);            

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_facet.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_facet.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_facet.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_facet.h Fri Mar 30 11:28:18 2007
@@ -29,7 +29,7 @@
 #include <xml_schema_defines.h>
 #include <axiom_element.h>
 #include <axiom_node.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 
 /** @defgroup xml_schema_facet Xml Schema Facet
   * @ingroup xml_schema
@@ -63,7 +63,7 @@
     get_type)(void *facet,
           const axutil_env_t *env);
           
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(void *facet,
                 const axutil_env_t *env);          
 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_form.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_form.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_form.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_form.h Fri Mar 30 11:28:18 2007
@@ -52,7 +52,7 @@
     free) (void *form,
             const axutil_env_t *env);
 
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs) (void *form,
             const axutil_env_t *env);
 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_group.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_group.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_group.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_group.h Fri Mar 30 11:28:18 2007
@@ -29,7 +29,7 @@
 
 #include <xml_schema_defines.h>
 #include <xml_schema_annotated.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 
 /** @defgroup xml_schema_group Xml Schema Group
   * @ingroup xml_schema
@@ -55,7 +55,7 @@
     free) (void *group,
             const axutil_env_t *env);
 
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs) (void *group,
             const axutil_env_t *env);
 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_group_base.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_group_base.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_group_base.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_group_base.h Fri Mar 30 11:28:18 2007
@@ -55,7 +55,7 @@
     free) (void *group_base,
             const axutil_env_t *env);
 
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs) (void *group_base,
             const axutil_env_t *env);
 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_group_ref.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_group_ref.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_group_ref.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_group_ref.h Fri Mar 30 11:28:18 2007
@@ -28,7 +28,7 @@
 
 #include <xml_schema_defines.h>
 #include <xml_schema_particle.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <axis2_qname.h>
 
 /** @defgroup_ref xml_schema_group_ref Xml Schema Group Ref
@@ -51,7 +51,7 @@
     free) (void *group_ref,
            const axutil_env_t *env);
 
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs) (
             void *group_ref,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_identity_constraint.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_identity_constraint.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_identity_constraint.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_identity_constraint.h Fri Mar 30 11:28:18 2007
@@ -25,7 +25,7 @@
  */
 
 #include <xml_schema_annotated.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <axis2_qname.h>
 
 /** @defidentity_constraint xml_schema_identity_constraint Xml Schema 
@@ -60,7 +60,7 @@
     get_base_impl) (void *id_constr,
                     const axutil_env_t *env);
                     
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs) (void *id_constr,
                 const axutil_env_t *env);
                 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_import.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_import.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_import.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_import.h Fri Mar 30 11:28:18 2007
@@ -25,7 +25,7 @@
  */
 
 #include <xml_schema_external.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 
 /** @defgroup xml_schema_include Xml Schema Particle
   * @ingroup xml_schema
@@ -55,7 +55,7 @@
                    const axutil_env_t *env);
 
 
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(void *import,
                 const axutil_env_t *env);
                 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_collection.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_collection.h Fri Mar 30 11:28:18 2007
@@ -30,7 +30,7 @@
 #include <axutil_error.h>
 #include <axis2_string.h>
 #include <axutil_array_list.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <xml_schema_obj.h>
 
 #ifdef __cplusplus

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_table.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_table.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_table.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_table.h Fri Mar 30 11:28:18 2007
@@ -39,7 +39,7 @@
 #include <axis2_string.h>
 #include <axis2_utils.h>
 #include <axutil_array_list.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <axis2_qname.h>
 #include <xml_schema_obj.h>
 
@@ -146,7 +146,7 @@
             axis2_char_t *key,
             void *value);
          
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     get_hash_table)(
             xml_schema_obj_table_t *obj_table,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_particle.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_particle.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_particle.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_particle.h Fri Mar 30 11:28:18 2007
@@ -26,7 +26,7 @@
 
 #include <xml_schema_defines.h>
 #include <xml_schema_annotated.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 
 /** @defgroup xml_schema_particle Xml Schema Particle
   * @ingroup xml_schema
@@ -54,7 +54,7 @@
             void *particle,
             const axutil_env_t *env);
 
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs) (
             void *particle,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_redefine.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_redefine.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_redefine.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_redefine.h Fri Mar 30 11:28:18 2007
@@ -25,7 +25,7 @@
  */
 
 #include <xml_schema_external.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <xml_schema_obj_table.h>
 #include <xml_schema_obj_collection.h>
 
@@ -56,7 +56,7 @@
     get_base_impl)(void *redefine,
                    const axutil_env_t *env);            
 
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(void *redefine,
                 const axutil_env_t *env);            
 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_severity_type.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_severity_type.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_severity_type.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_severity_type.h Fri Mar 30 11:28:18 2007
@@ -64,7 +64,7 @@
     get_values)(void *severity,
                 const axutil_env_t *env);
                 
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(void *severity,
                 const axutil_env_t *env);
                 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content.h Fri Mar 30 11:28:18 2007
@@ -28,7 +28,7 @@
  */
 
 #include <xml_schema_annotated.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 
 /** @defgroup xml_schema_simple_content Xml Schema Group
   * @ingroup xml_schema
@@ -58,7 +58,7 @@
     get_base_impl) (void *sim_content,
                     const axutil_env_t *env);
                     
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs) (void *sim_content,
                 const axutil_env_t *env);
                     

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_extension.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_extension.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_extension.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_extension.h Fri Mar 30 11:28:18 2007
@@ -30,7 +30,7 @@
 #include <xml_schema_annotated.h>
 #include <xml_schema_obj_collection.h>
 #include <xml_schema_any_attribute.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <axis2_qname.h>
 /** @defgroup xml_schema_simple_content_extension Xml Schema Group
   * @ingroup xml_schema
@@ -64,7 +64,7 @@
     get_type)(void *sim_content_ext,
           const axutil_env_t *env);
           
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(void *sim_content_ext,
                 const axutil_env_t *env);                              
 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_restriction.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_restriction.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_restriction.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_restriction.h Fri Mar 30 11:28:18 2007
@@ -31,7 +31,7 @@
 #include <xml_schema_obj_collection.h>
 #include <xml_schema_any_attribute.h>
 #include <xml_schema_simple_type.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <axis2_qname.h>
 
 /** @defgroup xml_schema_simple_content_restriction Xml Schema Group
@@ -61,7 +61,7 @@
             void *sim_content_res,
             const axutil_env_t *env);
             
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(
             void *sim_content_res,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type.h Fri Mar 30 11:28:18 2007
@@ -26,7 +26,7 @@
 
 #include <xml_schema_annotated.h>
 #include <xml_schema_type.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <axis2_qname.h>
 #include <xml_schema_simple_type_content.h>
 /** @defgroup xml_schema_simple_type Xml Schema Type
@@ -61,7 +61,7 @@
     get_type) (void *simple_type,
             const axutil_env_t *env);
                     
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs) (void *simple_type,
                  const axutil_env_t *env);                                        
                     
@@ -107,7 +107,7 @@
                                 xml_schema_simple_type_t *simple_type,
                                 const axutil_env_t *env,
                                 xml_schema_simple_type_t *type_impl,
-                                axis2_hash_t *methods);
+                                axutil_hash_t *methods);
  */
  /***************** Macros ***************************************************/
 #define XML_SCHEMA_SIMPLE_TYPE_FREE(simple_type, env) \

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_content.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_content.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_content.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_content.h Fri Mar 30 11:28:18 2007
@@ -25,7 +25,7 @@
  */
 
 #include <xml_schema_annotated.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 
 /** @defgroup xml_schema_simple_type_content Xml Schema Particle
   * @ingroup xml_schema
@@ -60,7 +60,7 @@
     get_type)(void *sim_type_cont,
               const axutil_env_t *env);
     
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(void *sim_type_cont,
                 const axutil_env_t *env);
     

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_list.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_list.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_list.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_list.h Fri Mar 30 11:28:18 2007
@@ -28,7 +28,7 @@
 #include <xml_schema_simple_type.h>
 #include <xml_schema_simple_type_content.h>
 #include <xml_schema_obj_collection.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 /** @defgroup xml_schema_simple_type_list 
   * @ingroup xml_schema
   * @{
@@ -61,7 +61,7 @@
     get_type)(void *simple_type_list,
           const axutil_env_t *env);
     
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(void *simple_type_list,
           const axutil_env_t *env);
           

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_restriction.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_restriction.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_restriction.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_restriction.h Fri Mar 30 11:28:18 2007
@@ -28,7 +28,7 @@
 #include <xml_schema_simple_type.h>
 #include <xml_schema_simple_type_content.h>
 #include <xml_schema_obj_collection.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 /** @defgroup xml_schema_simple_type_restriction 
   * @ingroup xml_schema
   * @{
@@ -57,7 +57,7 @@
     get_type)(void *simple_type_restriction,
                 const axutil_env_t *env);
                 
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs)(void *simple_type_restriction,
                 const axutil_env_t *env);                                    
 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_union.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_union.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_union.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_union.h Fri Mar 30 11:28:18 2007
@@ -28,7 +28,7 @@
 #include <xml_schema_simple_type.h>
 #include <xml_schema_simple_type_content.h>
 #include <xml_schema_obj_collection.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <axutil_array_list.h>
 /** @defgroup xml_schema_simple_type_union 
   * @ingroup xml_schema
@@ -54,7 +54,7 @@
             void *sim_type_union,
             const axutil_env_t *env);
                     
-    axis2_hash_t*(AXIS2_CALL *
+    axutil_hash_t*(AXIS2_CALL *
     super_objs)(
             void *sim_type_union,
             const axutil_env_t *env);                    

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_tokenized_type.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_tokenized_type.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_tokenized_type.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_tokenized_type.h Fri Mar 30 11:28:18 2007
@@ -59,7 +59,7 @@
     get_values)(void *tokenized_type,
                 const axutil_env_t *env);
                 
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(void *tokenized_type,
                 const axutil_env_t *env);
                 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_type.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_type.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_type.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_type.h Fri Mar 30 11:28:18 2007
@@ -25,7 +25,7 @@
  */
 
 #include <xml_schema_annotated.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <axis2_qname.h>
 
 /** @defgroup xml_schema_type Xml Schema Type
@@ -54,7 +54,7 @@
     get_base_impl) (void *type,
                     const axutil_env_t *env);
                     
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(void *type,
                 const axutil_env_t *env);
                    

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_use.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_use.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_use.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_use.h Fri Mar 30 11:28:18 2007
@@ -51,7 +51,7 @@
     free) (void *use,
             const axutil_env_t *env);
 
-    axis2_hash_t *(AXIS2_CALL *
+    axutil_hash_t *(AXIS2_CALL *
     super_objs) (
             void *use,
             const axutil_env_t *env);

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_xpath.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_xpath.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_xpath.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_xpath.h Fri Mar 30 11:28:18 2007
@@ -30,7 +30,7 @@
 #include <xml_schema_annotated.h>
 #include <axiom_element.h>
 #include <axiom_node.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 
 /** @defgroup xml_schema_xpath Xml Schema Xpath
   * @ingroup xml_schema
@@ -63,7 +63,7 @@
     get_type)(void *xpath,
           const axutil_env_t *env);
           
-    axis2_hash_t* (AXIS2_CALL *
+    axutil_hash_t* (AXIS2_CALL *
     super_objs)(void *xpath,
                 const axutil_env_t *env);
 

Modified: webservices/axis2/trunk/c/xml_schema/src/xml_schema.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/src/xml_schema.c?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/src/xml_schema.c (original)
+++ webservices/axis2/trunk/c/xml_schema/src/xml_schema.c Fri Mar 30 11:28:18 2007
@@ -30,7 +30,7 @@
 
     xml_schema_types_t obj_type;
 
-    axis2_hash_t *ht_super;
+    axutil_hash_t *ht_super;
 
     xml_schema_form_t *attr_form_default;
 
@@ -62,7 +62,7 @@
 
     axis2_char_t *version;
 
-    axis2_hash_t *namespaces_map;
+    axutil_hash_t *namespaces_map;
 
     axis2_char_t *schema_ns_prefix;
 
@@ -79,7 +79,7 @@
     void *schema,
     const axutil_env_t *env);
 
-axis2_hash_t *AXIS2_CALL
+axutil_hash_t *AXIS2_CALL
 xml_schema_super_objs(
     void *schema,
     const axutil_env_t *env);
@@ -239,7 +239,7 @@
         const axutil_env_t *env,
         void *writer);
 */
-axis2_hash_t *AXIS2_CALL
+axutil_hash_t *AXIS2_CALL
 xml_schema_get_prefix_to_namespace_map(
     void *schema,
     const axutil_env_t *env);
@@ -248,7 +248,7 @@
 xml_schema_set_prefix_to_namespace_map(
     void *schema,
     const axutil_env_t *env,
-    axis2_hash_t *map);
+    axutil_hash_t *map);
 
 axis2_status_t AXIS2_CALL
 xml_schema_add_type(
@@ -421,7 +421,7 @@
 
     schema_impl->includes = xml_schema_obj_collection_create(env);
 
-    schema_impl->namespaces_map = axis2_hash_make(env);
+    schema_impl->namespaces_map = axutil_hash_make(env);
 
     schema_impl->elements = xml_schema_obj_table_create(env);
 
@@ -437,19 +437,19 @@
 
     schema_impl->annotated = xml_schema_annotated_create(env);
 
-    schema_impl->ht_super = axis2_hash_make(env);
+    schema_impl->ht_super = axutil_hash_make(env);
     if (!schema_impl->ht_super)
     {
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
         return NULL;
     }
-    axis2_hash_set(schema_impl->ht_super, "XML_SCHEMA",
+    axutil_hash_set(schema_impl->ht_super, "XML_SCHEMA",
             AXIS2_HASH_KEY_STRING, &(schema_impl->schema));
 
-    axis2_hash_set(schema_impl->ht_super, "XML_SCHEMA_ANNOTATED",
+    axutil_hash_set(schema_impl->ht_super, "XML_SCHEMA_ANNOTATED",
             AXIS2_HASH_KEY_STRING, schema_impl->annotated);
 
-    axis2_hash_set(schema_impl->ht_super, "XML_SCHEMA_OBJ",
+    axutil_hash_set(schema_impl->ht_super, "XML_SCHEMA_OBJ",
             AXIS2_HASH_KEY_STRING,
             XML_SCHEMA_ANNOTATED_GET_BASE_IMPL(schema_impl->annotated, env));
 
@@ -492,16 +492,16 @@
     }
     if (schema_impl->elements)
     {
-        axis2_hash_t *ht = NULL;
-        axis2_hash_index_t *hi = NULL;
+        axutil_hash_t *ht = NULL;
+        axutil_hash_index_t *hi = NULL;
 
         ht = XML_SCHEMA_OBJ_TABLE_GET_HASH_TABLE(schema_impl->elements, env);
         if (ht)
         {
-            for (hi = axis2_hash_first(ht, env); hi; hi = axis2_hash_next(env, hi))
+            for (hi = axutil_hash_first(ht, env); hi; hi = axutil_hash_next(env, hi))
             {
                 void *val = NULL;
-                axis2_hash_this(hi, NULL, NULL, &val);
+                axutil_hash_this(hi, NULL, NULL, &val);
                 if (val)
                 {
                     if (XML_SCHEMA_OBJ_GET_TYPE(val, env) == XML_SCHEMA_ELEMENT)
@@ -518,7 +518,7 @@
 
     if (schema_impl->ht_super)
     {
-        axis2_hash_free(schema_impl->ht_super, env);
+        axutil_hash_free(schema_impl->ht_super, env);
         schema_impl->ht_super = NULL;
     }
 
@@ -555,7 +555,7 @@
     return schema_impl->obj_type;
 }
 
-axis2_hash_t *AXIS2_CALL
+axutil_hash_t *AXIS2_CALL
 xml_schema_super_objs(
     void *schema,
     const axutil_env_t *env)
@@ -588,7 +588,7 @@
     axis2_char_t *prefix)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_ENV_CHECK(env, NULL);
     AXIS2_PARAM_CHECK(env->error, prefix, NULL);
@@ -596,7 +596,7 @@
     if (ht_super)
     {
 
-        schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
         if (!schema_impl)
             return NULL;
@@ -604,7 +604,7 @@
     if (schema_impl->namespaces_map)
     {
         void *result = NULL;
-        result = axis2_hash_get(schema_impl->namespaces_map, prefix,
+        result = axutil_hash_get(schema_impl->namespaces_map, prefix,
                 AXIS2_HASH_KEY_STRING);
         if (result)
             return (axis2_char_t *)result ;
@@ -618,13 +618,13 @@
     const axutil_env_t *env)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (ht_super)
     {
-        schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
         if (!schema_impl)
             return NULL;
@@ -639,13 +639,13 @@
     xml_schema_form_t *value)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (ht_super)
     {
-        schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
         if (!schema_impl)
             return AXIS2_FAILURE;
@@ -664,13 +664,13 @@
     const axutil_env_t *env)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (ht_super)
     {
-        schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
         if (!schema_impl)
             return NULL;
@@ -685,13 +685,13 @@
     const axutil_env_t *env)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (ht_super)
     {
-        schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
         if (!schema_impl)
             return NULL;
@@ -705,13 +705,13 @@
     const axutil_env_t *env)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (ht_super)
     {
-        schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
         if (!schema_impl)
             return NULL;
@@ -726,13 +726,13 @@
     xml_schema_derivation_method_t *block_default)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (ht_super)
     {
-        schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
         if (!schema_impl)
             return AXIS2_FAILURE;
@@ -750,13 +750,13 @@
     const axutil_env_t *env)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (ht_super)
     {
-        schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
         if (!schema_impl)
             return NULL;
@@ -771,12 +771,12 @@
     xml_schema_form_t *element_form_default)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_PARAM_CHECK(env->error, element_form_default, AXIS2_FAILURE);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (ht_super)
     {
-        schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
         if (!schema_impl)
             return AXIS2_FAILURE;
@@ -796,13 +796,13 @@
     const axutil_env_t *env)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (ht_super)
     {
-        schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
         if (!schema_impl)
             return NULL;
@@ -817,13 +817,13 @@
     const axis2_qname_t *qname)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_PARAM_CHECK(env->error, qname, NULL);
 
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (ht_super)
     {
-        schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
         if (!schema_impl)
             return NULL;
@@ -843,7 +843,7 @@
     axis2_qname_t *qname)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, NULL);
     AXIS2_PARAM_CHECK(env->error, qname, NULL);
 
@@ -851,7 +851,7 @@
 
     if (ht_super)
     {
-        schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
         if (!schema_impl)
             return NULL;
@@ -870,14 +870,14 @@
     const axutil_env_t *env)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (!ht_super)
         return NULL;
 
-    schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+    schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
             "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
 
     if (!schema_impl)
@@ -893,13 +893,13 @@
     xml_schema_derivation_method_t *final_default)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (!ht_super)
         return AXIS2_FAILURE;
 
-    schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+    schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
             "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
 
     if (!schema_impl)
@@ -919,12 +919,12 @@
     const axutil_env_t *env)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (!ht_super)
         return NULL;
-    schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+    schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
             "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
     if (!schema_impl)
         return NULL;
@@ -936,12 +936,12 @@
         const axutil_env_t *env)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (!ht_super)
         return NULL;
-    schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+    schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
             "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
     if (!schema_impl)
         return NULL;
@@ -955,7 +955,7 @@
     const axutil_env_t *env)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
 
@@ -963,7 +963,7 @@
     if (!ht_super)
         return AXIS2_FAILURE;
 
-    schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+    schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
             "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
 
     if (!schema_impl)
@@ -978,14 +978,14 @@
     const axutil_env_t *env)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
 
     if (!ht_super)
         return NULL;
 
-    schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+    schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
             "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
 
     if (!schema_impl)
@@ -1000,14 +1000,14 @@
     const axutil_env_t *env)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
 
     if (!ht_super)
         return NULL;
 
-    schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+    schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
             "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
     if (!schema_impl)
         return NULL;
@@ -1020,12 +1020,12 @@
     const axutil_env_t *env)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (!ht_super)
         return NULL;
-    schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+    schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
             "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
     if (!schema_impl)
         return NULL;
@@ -1058,12 +1058,12 @@
 {
     xml_schema_impl_t *schema_impl = NULL;
 
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (!ht_super)
         return AXIS2_FAILURE;
-    schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+    schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
             "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
     if (!schema_impl)
         return AXIS2_FAILURE;
@@ -1083,12 +1083,12 @@
         const axutil_env_t *env)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
     if (!ht_super)
         return NULL;
-    schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+    schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
             "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
     if (!schema_impl)
         return NULL;
@@ -1135,17 +1135,17 @@
                     void *writer)
 {
     xml_schema_impl_t *schema_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_ENV_CHECK(env,  AXIS2_FAILURE);
     ht_super = XML_SCHEMA_SUPER_OBJS(schema, env);
-    schema_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+    schema_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
         "XML_SCHEMA", AXIS2_HASH_KEY_STRING));
 
     return AXIS2_SUCCESS;
 }
 */
-axis2_hash_t *AXIS2_CALL
+axutil_hash_t *AXIS2_CALL
 xml_schema_get_prefix_to_namespace_map(
     void *schema,
     const axutil_env_t *env)
@@ -1161,7 +1161,7 @@
 xml_schema_set_prefix_to_namespace_map(
     void *schema,
     const axutil_env_t *env,
-    axis2_hash_t *map)
+    axutil_hash_t *map)
 {
     xml_schema_impl_t *schema_impl = NULL;
 

Modified: webservices/axis2/trunk/c/xml_schema/src/xml_schema_annotated.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/src/xml_schema_annotated.c?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/src/xml_schema_annotated.c (original)
+++ webservices/axis2/trunk/c/xml_schema/src/xml_schema_annotated.c Fri Mar 30 11:28:18 2007
@@ -34,7 +34,7 @@
 
     xml_schema_types_t obj_type;
 
-    axis2_hash_t *ht_super;
+    axutil_hash_t *ht_super;
 
     xml_schema_annotation_t *annotation;
 
@@ -53,7 +53,7 @@
     void *annotated,
     const axutil_env_t *env);
 
-axis2_hash_t *AXIS2_CALL
+axutil_hash_t *AXIS2_CALL
 xml_schema_annotated_super_objs(
     void *annotated,
     const axutil_env_t *env);
@@ -159,17 +159,17 @@
         return NULL;
     }
 
-    annotated_impl->ht_super = axis2_hash_make(env);
+    annotated_impl->ht_super = axutil_hash_make(env);
     if (!annotated_impl->ht_super)
     {
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
         return NULL;
     }
-    axis2_hash_set(annotated_impl->ht_super,
+    axutil_hash_set(annotated_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_ANNOTATED"),
             AXIS2_HASH_KEY_STRING, &(annotated_impl->annotated));
 
-    axis2_hash_set(annotated_impl->ht_super,
+    axutil_hash_set(annotated_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_OBJ"), AXIS2_HASH_KEY_STRING,
             annotated_impl->schema_obj);
 
@@ -212,7 +212,7 @@
 
     if (annotated_impl->ht_super)
     {
-        axis2_hash_free(annotated_impl->ht_super, env);
+        axutil_hash_free(annotated_impl->ht_super, env);
         annotated_impl->ht_super = NULL;
     }
 
@@ -238,7 +238,7 @@
     return AXIS2_SUCCESS;
 }
 
-axis2_hash_t *AXIS2_CALL
+axutil_hash_t *AXIS2_CALL
 xml_schema_annotated_super_objs(
     void *annotated,
     const axutil_env_t *env)
@@ -318,14 +318,14 @@
         const axutil_env_t *env)
 {
     xml_schema_annotated_impl_t *annotated_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_ANNOTATED_SUPER_OBJS(annotated, env);
     if (ht_super)
     {
         annotated_impl = (xml_schema_annotated_impl_t*)
-                axis2_hash_get(ht_super, "XML_SCHEMA_ANNOTATED",
+                axutil_hash_get(ht_super, "XML_SCHEMA_ANNOTATED",
                         AXIS2_HASH_KEY_STRING);
         if (!annotated_impl)
             return NULL;
@@ -340,7 +340,7 @@
         axis2_char_t *id)
 {
     xml_schema_annotated_impl_t *annotated_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK(env->error, id, AXIS2_FAILURE);
@@ -349,7 +349,7 @@
     if (ht_super)
     {
         annotated_impl = (xml_schema_annotated_impl_t*)
-                axis2_hash_get(ht_super, "XML_SCHEMA_ANNOTATED",
+                axutil_hash_get(ht_super, "XML_SCHEMA_ANNOTATED",
                         AXIS2_HASH_KEY_STRING);
         if (!annotated_impl)
             return AXIS2_FAILURE;
@@ -369,13 +369,13 @@
         const axutil_env_t *env)
 {
     xml_schema_annotated_impl_t *annotated_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_ANNOTATED_SUPER_OBJS(annotated, env);
     if (ht_super)
     {
         annotated_impl = (xml_schema_annotated_impl_t*)
-                axis2_hash_get(ht_super, "XML_SCHEMA_ANNOTATED",
+                axutil_hash_get(ht_super, "XML_SCHEMA_ANNOTATED",
                         AXIS2_HASH_KEY_STRING);
         if (!annotated_impl)
             return NULL;
@@ -390,13 +390,13 @@
         annotation)
 {
     xml_schema_annotated_impl_t *annotated_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
     ht_super = XML_SCHEMA_ANNOTATED_SUPER_OBJS(annotated, env);
     if (ht_super)
     {
         annotated_impl = (xml_schema_annotated_impl_t*)
-                axis2_hash_get(ht_super, "XML_SCHEMA_ANNOTATED",
+                axutil_hash_get(ht_super, "XML_SCHEMA_ANNOTATED",
                         AXIS2_HASH_KEY_STRING);
         if (!annotated_impl)
             return AXIS2_FAILURE;
@@ -417,13 +417,13 @@
         const axutil_env_t *env)
 {
     xml_schema_annotated_impl_t *annotated_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_ANNOTATED_SUPER_OBJS(annotated, env);
     if (ht_super)
     {
         annotated_impl = (xml_schema_annotated_impl_t*)
-                axis2_hash_get(ht_super, "XML_SCHEMA_ANNOTATED",
+                axutil_hash_get(ht_super, "XML_SCHEMA_ANNOTATED",
                         AXIS2_HASH_KEY_STRING);
         if (!annotated_impl)
             return NULL;
@@ -438,13 +438,13 @@
         unhandled_attrs)
 {
     xml_schema_annotated_impl_t *annotated_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
     ht_super = XML_SCHEMA_ANNOTATED_SUPER_OBJS(annotated, env);
     if (ht_super)
     {
         annotated_impl = (xml_schema_annotated_impl_t*)
-                axis2_hash_get(ht_super, "XML_SCHEMA_ANNOTATED",
+                axutil_hash_get(ht_super, "XML_SCHEMA_ANNOTATED",
                         AXIS2_HASH_KEY_STRING);
         if (!annotated_impl)
             return AXIS2_FAILURE;

Modified: webservices/axis2/trunk/c/xml_schema/src/xml_schema_annotation.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/src/xml_schema_annotation.c?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/src/xml_schema_annotation.c (original)
+++ webservices/axis2/trunk/c/xml_schema/src/xml_schema_annotation.c Fri Mar 30 11:28:18 2007
@@ -28,7 +28,7 @@
 
     xml_schema_types_t obj_type;
 
-    axis2_hash_t *ht_super;
+    axutil_hash_t *ht_super;
 
     xml_schema_obj_t *schema_obj;
 
@@ -47,7 +47,7 @@
     void *annotation,
     const axutil_env_t *env);
 
-axis2_hash_t *AXIS2_CALL
+axutil_hash_t *AXIS2_CALL
 xml_schema_annotation_super_objs(
     void *annotation,
     const axutil_env_t *env);
@@ -127,18 +127,18 @@
         return NULL;
     }
 
-    annotation_impl->ht_super = axis2_hash_make(env);
+    annotation_impl->ht_super = axutil_hash_make(env);
     if (!annotation_impl->ht_super)
     {
         xml_schema_annotation_free(&(annotation_impl->annotation), env);
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
         return NULL;
     }
-    axis2_hash_set(annotation_impl->ht_super,
+    axutil_hash_set(annotation_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_ANNOTATION"),
             AXIS2_HASH_KEY_STRING, &(annotation_impl->annotation));
 
-    axis2_hash_set(annotation_impl->ht_super,
+    axutil_hash_set(annotation_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_OBJ"),
             AXIS2_HASH_KEY_STRING, annotation_impl->schema_obj);
 
@@ -168,7 +168,7 @@
 
     if (annotation_impl->ht_super)
     {
-        axis2_hash_free(annotation_impl->ht_super, env);
+        axutil_hash_free(annotation_impl->ht_super, env);
         annotation_impl->ht_super = NULL;
     }
 
@@ -213,7 +213,7 @@
     return AXIS2_INTF_TO_IMPL(annotation)->items;
 }
 
-axis2_hash_t *AXIS2_CALL
+axutil_hash_t *AXIS2_CALL
 xml_schema_annotation_super_objs(
     void *annotation,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/xml_schema/src/xml_schema_any.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/src/xml_schema_any.c?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/src/xml_schema_any.c (original)
+++ webservices/axis2/trunk/c/xml_schema/src/xml_schema_any.c Fri Mar 30 11:28:18 2007
@@ -33,7 +33,7 @@
 
     xml_schema_types_t obj_type;
 
-    axis2_hash_t *ht_super;
+    axutil_hash_t *ht_super;
 
     xml_schema_content_processing_t *process_content;
     /**
@@ -50,7 +50,7 @@
     void *any,
     const axutil_env_t *env);
 
-axis2_hash_t *AXIS2_CALL
+axutil_hash_t *AXIS2_CALL
 xml_schema_any_super_objs(
     void *any,
     const axutil_env_t *env);
@@ -151,28 +151,28 @@
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
         return NULL;
     }
-    any_impl->ht_super = axis2_hash_make(env);
+    any_impl->ht_super = axutil_hash_make(env);
     if (!any_impl->ht_super)
     {
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
         return NULL;
     }
-    axis2_hash_set(any_impl->ht_super,
+    axutil_hash_set(any_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_ANY"),
             AXIS2_HASH_KEY_STRING, &(any_impl->any));
 
-    axis2_hash_set(any_impl->ht_super,
+    axutil_hash_set(any_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_PARTICLE"),
             AXIS2_HASH_KEY_STRING, any_impl->particle);
 
     annotated = XML_SCHEMA_PARTICLE_GET_BASE_IMPL(any_impl->particle, env);
     if (annotated)
     {
-        axis2_hash_set(any_impl->ht_super,
+        axutil_hash_set(any_impl->ht_super,
                 axis2_strdup(env, "XML_SCHEMA_ANNOTATED"),
                 AXIS2_HASH_KEY_STRING, annotated);
 
-        axis2_hash_set(any_impl->ht_super,
+        axutil_hash_set(any_impl->ht_super,
                 axis2_strdup(env, "XML_SCHEMA_OBJ"),
                 AXIS2_HASH_KEY_STRING, XML_SCHEMA_ANNOTATED_GET_BASE_IMPL(annotated, env));
     }
@@ -208,7 +208,7 @@
 
     if (any_impl->ht_super)
     {
-        axis2_hash_free(any_impl->ht_super, env);
+        axutil_hash_free(any_impl->ht_super, env);
         any_impl->ht_super = NULL;
     }
 
@@ -244,7 +244,7 @@
     return any_impl->obj_type;
 }
 
-axis2_hash_t *AXIS2_CALL
+axutil_hash_t *AXIS2_CALL
 xml_schema_any_super_objs(
     void *any,
     const axutil_env_t *env)
@@ -314,12 +314,12 @@
         const axutil_env_t *env)
 {
     xml_schema_any_impl_t *any_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     ht_super = XML_SCHEMA_ANY_SUPER_OBJS(any, env);
     if (ht_super)
     {
-        any_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        any_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA_ANY", AXIS2_HASH_KEY_STRING));
         if (!any_impl)
             return NULL;
@@ -333,13 +333,13 @@
         axis2_char_t *namespc)
 {
     xml_schema_any_impl_t *any_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_PARAM_CHECK(env->error, namespc, AXIS2_FAILURE);
 
     ht_super = XML_SCHEMA_ANY_SUPER_OBJS(any, env);
     if (ht_super)
     {
-        any_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        any_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA_ANY", AXIS2_HASH_KEY_STRING));
         if (!any_impl)
             return AXIS2_FAILURE;
@@ -358,12 +358,12 @@
         const axutil_env_t *env)
 {
     xml_schema_any_impl_t *any_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     ht_super = XML_SCHEMA_ANY_SUPER_OBJS(any, env);
     if (ht_super)
     {
-        any_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        any_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA_ANY", AXIS2_HASH_KEY_STRING));
         if (!any_impl)
             return NULL;
@@ -378,7 +378,7 @@
         process_content)
 {
     xml_schema_any_impl_t *any_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
 
     AXIS2_PARAM_CHECK(env->error, process_content, AXIS2_FAILURE);
 
@@ -386,7 +386,7 @@
 
     if (ht_super)
     {
-        any_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super,
+        any_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super,
                 "XML_SCHEMA_ANY", AXIS2_HASH_KEY_STRING));
         if (!any_impl)
             return AXIS2_FAILURE;

Modified: webservices/axis2/trunk/c/xml_schema/src/xml_schema_any_attribute.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/src/xml_schema_any_attribute.c?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/src/xml_schema_any_attribute.c (original)
+++ webservices/axis2/trunk/c/xml_schema/src/xml_schema_any_attribute.c Fri Mar 30 11:28:18 2007
@@ -37,7 +37,7 @@
      */
     xml_schema_types_t obj_type;
 
-    axis2_hash_t* ht_super;
+    axutil_hash_t* ht_super;
 
     axis2_char_t *ns;
 };
@@ -58,7 +58,7 @@
 xml_schema_any_attribute_get_type(void *any_attr,
         const axutil_env_t *env);
 
-axis2_hash_t* AXIS2_CALL
+axutil_hash_t* AXIS2_CALL
 xml_schema_any_attribute_super_objs(void *any_attr,
         const axutil_env_t *env);
 
@@ -150,22 +150,22 @@
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
     }
 
-    any_attr_impl->ht_super = axis2_hash_make(env);
+    any_attr_impl->ht_super = axutil_hash_make(env);
     if (!any_attr_impl->ht_super)
     {
         xml_schema_any_attribute_free(&(any_attr_impl->any_attr), env);
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
         return NULL;
     }
-    axis2_hash_set(any_attr_impl->ht_super,
+    axutil_hash_set(any_attr_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_ANY_ATTRIBUTE"),
             AXIS2_HASH_KEY_STRING, &(any_attr_impl->any_attr));
 
-    axis2_hash_set(any_attr_impl->ht_super,
+    axutil_hash_set(any_attr_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_ANNOTATED"),
             AXIS2_HASH_KEY_STRING, any_attr_impl->annotated);
 
-    axis2_hash_set(any_attr_impl->ht_super,
+    axutil_hash_set(any_attr_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_OBJ"),
             AXIS2_HASH_KEY_STRING,
             XML_SCHEMA_ANNOTATED_GET_BASE_IMPL(any_attr_impl->annotated, env));
@@ -194,7 +194,7 @@
     }
     if (any_attr_impl->ht_super)
     {
-        axis2_hash_free(any_attr_impl->ht_super, env);
+        axutil_hash_free(any_attr_impl->ht_super, env);
         any_attr_impl->ht_super = NULL;
     }
     if (any_attr_impl->process_content)
@@ -304,7 +304,7 @@
     return AXIS2_INTF_TO_IMPL(any_attr)->obj_type;
 }
 
-axis2_hash_t* AXIS2_CALL
+axutil_hash_t* AXIS2_CALL
 xml_schema_any_attribute_super_objs(void *any_attr,
         const axutil_env_t *env)
 {

Modified: webservices/axis2/trunk/c/xml_schema/src/xml_schema_app_info.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/src/xml_schema_app_info.c?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/src/xml_schema_app_info.c (original)
+++ webservices/axis2/trunk/c/xml_schema/src/xml_schema_app_info.c Fri Mar 30 11:28:18 2007
@@ -35,7 +35,7 @@
 
     xml_schema_types_t obj_type;
 
-    axis2_hash_t *ht_super;
+    axutil_hash_t *ht_super;
 
     axis2_char_t *source;
 
@@ -50,7 +50,7 @@
     void *app_info,
     const axutil_env_t *env);
 
-axis2_hash_t *AXIS2_CALL
+axutil_hash_t *AXIS2_CALL
 xml_schema_app_info_super_objs(
     void *app_info,
     const axutil_env_t *env);
@@ -147,7 +147,7 @@
         return NULL;
     }
 
-    app_info_impl->ht_super = axis2_hash_make(env);
+    app_info_impl->ht_super = axutil_hash_make(env);
 
     if (!app_info_impl->ht_super)
     {
@@ -155,11 +155,11 @@
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
         return NULL;
     }
-    axis2_hash_set(app_info_impl->ht_super,
+    axutil_hash_set(app_info_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_APP_INFO"),
             AXIS2_HASH_KEY_STRING, &(app_info_impl->app_info));
 
-    axis2_hash_set(app_info_impl->ht_super,
+    axutil_hash_set(app_info_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_OBJ"),
             AXIS2_HASH_KEY_STRING, app_info_impl->schema_obj);
 
@@ -191,7 +191,7 @@
 
     if (app_info_impl->ht_super)
     {
-        axis2_hash_free(app_info_impl->ht_super, env);
+        axutil_hash_free(app_info_impl->ht_super, env);
         app_info_impl->ht_super = NULL;
     }
 
@@ -219,7 +219,7 @@
     return AXIS2_SUCCESS;
 }
 
-axis2_hash_t *AXIS2_CALL
+axutil_hash_t *AXIS2_CALL
 xml_schema_app_info_super_objs(
     void *app_info,
     const axutil_env_t *env)
@@ -249,12 +249,12 @@
 {
 
     xml_schema_app_info_impl_t *app_info_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_USE_SUPER_OBJS(app_info, env);
     if (ht_super)
     {
-        app_info_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super, "XML_SCHEMA_APP_INFO",
+        app_info_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super, "XML_SCHEMA_APP_INFO",
                 AXIS2_HASH_KEY_STRING));
         if (app_info_impl)
             return  app_info_impl->source;
@@ -269,14 +269,14 @@
         axis2_char_t *source)
 {
     xml_schema_app_info_impl_t *app_info_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK(env->error, source, AXIS2_FAILURE);
 
     ht_super = XML_SCHEMA_USE_SUPER_OBJS(app_info, env);
     if (ht_super)
     {
-        app_info_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super, "XML_SCHEMA_APP_INFO",
+        app_info_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super, "XML_SCHEMA_APP_INFO",
                 AXIS2_HASH_KEY_STRING));
         if (app_info_impl)
             return  AXIS2_FAILURE;
@@ -303,12 +303,12 @@
         const axutil_env_t *env)
 {
     xml_schema_app_info_impl_t *app_info_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, NULL);
     ht_super = XML_SCHEMA_USE_SUPER_OBJS(app_info, env);
     if (ht_super)
     {
-        app_info_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super, "XML_SCHEMA_APP_INFO",
+        app_info_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super, "XML_SCHEMA_APP_INFO",
                 AXIS2_HASH_KEY_STRING));
         if (app_info_impl)
             return  NULL;
@@ -323,13 +323,13 @@
         void *markup)
 {
     xml_schema_app_info_impl_t *app_info_impl = NULL;
-    axis2_hash_t *ht_super = NULL;
+    axutil_hash_t *ht_super = NULL;
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK(env->error, markup, AXIS2_FAILURE);
     ht_super = XML_SCHEMA_USE_SUPER_OBJS(app_info, env);
     if (ht_super)
     {
-        app_info_impl = AXIS2_INTF_TO_IMPL(axis2_hash_get(ht_super, "XML_SCHEMA_APP_INFO",
+        app_info_impl = AXIS2_INTF_TO_IMPL(axutil_hash_get(ht_super, "XML_SCHEMA_APP_INFO",
                 AXIS2_HASH_KEY_STRING));
         if (app_info_impl)
             return  AXIS2_FAILURE;

Modified: webservices/axis2/trunk/c/xml_schema/src/xml_schema_attribute.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/src/xml_schema_attribute.c?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/src/xml_schema_attribute.c (original)
+++ webservices/axis2/trunk/c/xml_schema/src/xml_schema_attribute.c Fri Mar 30 11:28:18 2007
@@ -53,7 +53,7 @@
 
     xml_schema_types_t obj_type;
 
-    axis2_hash_t* ht_super;
+    axutil_hash_t* ht_super;
 };
 
 #define AXIS2_INTF_TO_IMPL(attr) \
@@ -72,7 +72,7 @@
 xml_schema_attribute_get_type(void *attr,
         const axutil_env_t *env);
 
-axis2_hash_t* AXIS2_CALL
+axutil_hash_t* AXIS2_CALL
 xml_schema_attribute_super_objs(void *attr,
         const axutil_env_t *env);
 
@@ -266,7 +266,7 @@
     attr_impl->attr.ops->to_string =
         xml_schema_attribute_to_string;
 
-    attr_impl->ht_super = axis2_hash_make(env);
+    attr_impl->ht_super = axutil_hash_make(env);
     if (!attr_impl->ht_super)
     {
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
@@ -281,15 +281,15 @@
         return NULL;
     }
 
-    axis2_hash_set(attr_impl->ht_super,
+    axutil_hash_set(attr_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_ATTRIBUTE"),
             AXIS2_HASH_KEY_STRING, &(attr_impl->attr));
 
-    axis2_hash_set(attr_impl->ht_super,
+    axutil_hash_set(attr_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_ANNOTATED"),
             AXIS2_HASH_KEY_STRING, attr_impl->annotated);
 
-    axis2_hash_set(attr_impl->ht_super,
+    axutil_hash_set(attr_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_OBJ"),
             AXIS2_HASH_KEY_STRING,
             XML_SCHEMA_ANNOTATED_GET_BASE_IMPL(attr_impl->annotated, env));
@@ -317,7 +317,7 @@
     }
     if (attr_impl->ht_super)
     {
-        axis2_hash_free(attr_impl->ht_super, env);
+        axutil_hash_free(attr_impl->ht_super, env);
         attr_impl->ht_super = NULL;
     }
     if (attr_impl->default_value)
@@ -387,7 +387,7 @@
     return AXIS2_INTF_TO_IMPL(attr)->obj_type;
 }
 
-axis2_hash_t* AXIS2_CALL
+axutil_hash_t* AXIS2_CALL
 xml_schema_attribute_super_objs(void *attr,
         const axutil_env_t *env)
 {

Modified: webservices/axis2/trunk/c/xml_schema/src/xml_schema_attribute_group.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/src/xml_schema_attribute_group.c?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/src/xml_schema_attribute_group.c (original)
+++ webservices/axis2/trunk/c/xml_schema/src/xml_schema_attribute_group.c Fri Mar 30 11:28:18 2007
@@ -38,7 +38,7 @@
 
     xml_schema_types_t obj_type;
 
-    axis2_hash_t* ht_super;
+    axutil_hash_t* ht_super;
 };
 
 #define AXIS2_INTF_TO_IMPL(attr_grp) \
@@ -59,7 +59,7 @@
     void *attr_grp,
     const axutil_env_t *env);
 
-axis2_hash_t* AXIS2_CALL
+axutil_hash_t* AXIS2_CALL
 xml_schema_attribute_group_super_objs(void *attr_grp,
         const axutil_env_t *env);
 
@@ -148,7 +148,7 @@
     attr_impl->attr_grp.ops->set_name =
         xml_schema_attribute_group_set_name;
 
-    attr_impl->ht_super = axis2_hash_make(env);
+    attr_impl->ht_super = axutil_hash_make(env);
     if (!attr_impl->ht_super)
     {
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
@@ -163,15 +163,15 @@
         return NULL;
     }
 
-    axis2_hash_set(attr_impl->ht_super,
+    axutil_hash_set(attr_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_ATTRIBUTE"),
             AXIS2_HASH_KEY_STRING, &(attr_impl->attr_grp));
 
-    axis2_hash_set(attr_impl->ht_super,
+    axutil_hash_set(attr_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_ANNOTATED"),
             AXIS2_HASH_KEY_STRING, attr_impl->annotated);
 
-    axis2_hash_set(attr_impl->ht_super,
+    axutil_hash_set(attr_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_OBJ"),
             AXIS2_HASH_KEY_STRING,
             XML_SCHEMA_ANNOTATED_GET_BASE_IMPL(attr_impl->annotated, env));
@@ -195,7 +195,7 @@
 
     if (attr_impl->ht_super)
     {
-        axis2_hash_free(attr_impl->ht_super, env);
+        axutil_hash_free(attr_impl->ht_super, env);
         attr_impl->ht_super = NULL;
     }
     if (attr_impl->any_attribute)
@@ -255,7 +255,7 @@
     return AXIS2_INTF_TO_IMPL(attr_grp)->obj_type;
 }
 
-axis2_hash_t* AXIS2_CALL
+axutil_hash_t* AXIS2_CALL
 xml_schema_attribute_group_super_objs(void *attr_grp,
         const axutil_env_t *env)
 {

Modified: webservices/axis2/trunk/c/xml_schema/src/xml_schema_attribute_group_ref.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/src/xml_schema_attribute_group_ref.c?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/src/xml_schema_attribute_group_ref.c (original)
+++ webservices/axis2/trunk/c/xml_schema/src/xml_schema_attribute_group_ref.c Fri Mar 30 11:28:18 2007
@@ -36,7 +36,7 @@
 
     xml_schema_types_t obj_type;
 
-    axis2_hash_t* ht_super;
+    axutil_hash_t* ht_super;
 };
 
 #define AXIS2_INTF_TO_IMPL(grp_ref) \
@@ -58,7 +58,7 @@
     void *grp_ref,
     const axutil_env_t *env);
 
-axis2_hash_t* AXIS2_CALL
+axutil_hash_t* AXIS2_CALL
 xml_schema_attribute_group_ref_super_objs(void *grp_ref,
         const axutil_env_t *env);
 
@@ -120,7 +120,7 @@
     attr_impl->grp_ref.ops->set_ref_qname =
         xml_schema_attribute_group_ref_set_ref_qname;
 
-    attr_impl->ht_super = axis2_hash_make(env);
+    attr_impl->ht_super = axutil_hash_make(env);
     if (!attr_impl->ht_super)
     {
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
@@ -135,15 +135,15 @@
         return NULL;
     }
 
-    axis2_hash_set(attr_impl->ht_super,
+    axutil_hash_set(attr_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_ATTRIBUTE"),
             AXIS2_HASH_KEY_STRING, &(attr_impl->grp_ref));
 
-    axis2_hash_set(attr_impl->ht_super,
+    axutil_hash_set(attr_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_ANNOTATED"),
             AXIS2_HASH_KEY_STRING, attr_impl->annotated);
 
-    axis2_hash_set(attr_impl->ht_super,
+    axutil_hash_set(attr_impl->ht_super,
             axis2_strdup(env, "XML_SCHEMA_OBJ"),
             AXIS2_HASH_KEY_STRING,
             XML_SCHEMA_ANNOTATED_GET_BASE_IMPL(attr_impl->annotated, env));
@@ -168,7 +168,7 @@
 
     if (attr_impl->ht_super)
     {
-        axis2_hash_free(attr_impl->ht_super, env);
+        axutil_hash_free(attr_impl->ht_super, env);
         attr_impl->ht_super = NULL;
     }
     if (attr_impl->ref_qname)
@@ -219,7 +219,7 @@
     return AXIS2_INTF_TO_IMPL(grp_ref)->obj_type;
 }
 
-axis2_hash_t* AXIS2_CALL
+axutil_hash_t* AXIS2_CALL
 xml_schema_attribute_group_ref_super_objs(
     void *grp_ref,
     const axutil_env_t *env)



---------------------------------------------------------------------
To unsubscribe, e-mail: axis-cvs-unsubscribe@ws.apache.org
For additional commands, e-mail: axis-cvs-help@ws.apache.org
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj.h Fri Mar 30 11:28:18 2007
@@ -39,7 +39,7 @@
 #include <axis2_string.h>
 #include <axis2_utils_defines.h>
 #include <axutil_array_list.h>
-#include <axis2_hash.h>
+#include <axutil_hash.h>
 #include <xml_schema_defines.h>
 #include <xml_schema_constants.h>
 
@@ -76,7 +76,7 @@
          * NULL otherwise
          */
 
-        axis2_hash_t *(AXIS2_CALL *
+        axutil_hash_t *(AXIS2_CALL *
                 super_objs) (
                     void *obj,
                     const axutil_env_t *env);
@@ -205,9 +205,9 @@
          * contain any meta infomation.
          * @param obj xml_schema_obj or its subtype 
          * @param env environment struct
          * @returns pointer to axis2_hash_t , NULL of not intialized
          */
-        axis2_hash_t* (AXIS2_CALL *
+        axutil_hash_t* (AXIS2_CALL *
                 get_meta_info)(
                         void *obj,
                         const axutil_env_t *env);
@@ -205,9 +205,9 @@
          * @param obj xml_schema_obj or its subtype 
          * @param env environment struct
-         * @returns pointer to axis2_hash_t , NULL of not intialized
+         * @returns pointer to axutil_hash_t , NULL of not intialized
          */

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_collection.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_collection.h?view=diff&rev=524225&r1=524224&r2=524225
==============================================================================